@@ -1,11 +1,18 @@
 import json
 
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 from cachetools import TTLCache
 
-__all__ = ('Cache',)
+__all__ = ('StaticCache','Cache')
 
 class Cache:
+    async def get(self, key: str) -> Optional[Dict[str, Any]]:
+        pass
+
+    async def set(self, key: str, value: Dict[str, Any]) -> None:
+        pass
+
+class StaticCache:
     def __init__(self, maxsize: int, ttl: int) -> None:
         self.cache = TTLCache(maxsize, ttl)
 
