@@ -20,6 +20,8 @@ class Language(str, Enum):
     FR = "fr"
     ES = "es"
     DE = "de"
+    IT = "it"
+    TR = "tr"
 
     """
         zh-CN: CHT
@@ -59,3 +61,8 @@ class EquipType(str, Enum):
     Sands = "EQUIP_SHOES"
     Goblet = "EQUIP_RING"
     Circlet = "EQUIP_DRESS"
+
+class ProfileRank(int, Enum):
+    TIER_1 = 0
+    TIER_2 = 1
+    TIER_3 = 2
\ No newline at end of file
